import axios from 'axios';

export interface Datum {
    id: number;
    created_at: Date;
    updated_at: Date;
    img: string;
    start_time: Date;
    end_time: Date;
    address: string;
    title: string;
    type: string;
    volunteer: number;
    servants: number;
    volunteer_max: number;
    servants_max: number;
}

export interface res_projects {
    status: string;
    code: number;
    data: Datum[];
    message: string;
}

export interface Data {
    url: string;
    name: string;
    size: number;
}

export interface update_img {
    url: any;
    code: number;
    msg: string;
    data: Data;
}

export interface projectRegister {
    [x: string]: any;
    status: string;  // 状态信息
    code: number;    // 状态码
    data: {
        project: {
            id: number;               // 项目 ID
            created_at: Date;         // 项目创建时间
            updated_at: Date;         // 项目更新时间
            img: string;              // 项目图片 URL
            start_time: Date;         // 项目开始时间
            end_time: Date;           // 项目结束时间
            address: string;          // 项目地址
            title: string;            // 项目标题
            type: string;             // 项目类型
        };
        projectdetailed: {
            created_at: Date;               // 创建时间
            updated_at: Date;               // 更新时间
            projectid: number;              // 项目 ID
            serviceduration: number;        // 服务时长
            recruitingpersonnel: number;    // 招募人员数量
            registerserve: number;          // 已注册的服务数量
            servicedescription: string;     // 服务描述
            totalnumberoftimecoins: number; // 总时长的时间币数量
            volunteergender: number;        // 志愿者性别
            volunteerage: number;           // 志愿者年龄范围
            registrationisclosed: Date;     // 注册结束时间
        };
        projectRegister: {
            id: number;               // 注册记录 ID
            created_at: Date;         // 创建时间
            updated_at: Date;         // 更新时间
            projectid: number;        // 项目 ID
            type: number;             // 注册类型
            userid: number;           // 用户 ID
        }[];
        volunteer: number;          // 已注册的志愿者数量
        servants: number;           // 已注册的服务人员数量
        volunteer_max: number;      // 最大志愿者数量
        servants_max: number;       // 最大服务人员数量
    };
    message: string; // 返回的消息
}



export function getproject() {
    return axios.post<res_projects>('/Apiv1/get_project');
}
/**
 * 获取单个项目详情
 * @param id
 * @returns
 */
export function getprojectDetailed(projectid: number) {
    return axios.post<projectRegister>('/Apiv1/get_projectdetailed', { projectid });
}

/**
 * 文件上传函数
 * @param file 
 * @returns 
 */
export function updateimage(file: string | Blob) {
    const formData = new FormData();
    formData.append('file', file);
    return axios.post<update_img>('/admin/api/v1/Upload/image', formData);
}
/**
 * 删除项目
 * @param id 项目id
 * @returns
 */
export function Del(id: Number) {
    return axios.post<update_img>('/admin/api/v1/project/del', { projectid: id });
}
/**
 * 更新函数 id为0则是新建
 * @param id 
 * @param img 
 * @param start_time 
 * @param end_time 
 * @param address 
 * @param title 
 * @param type 
 * @param recruitingpersonnel 
 * @param registerserve 
 * @param servicedescription 
 * @param totalnumberoftimecoins 
 * @param volunteergender 
 * @param volunteerage 
 * @param registrationisclosed 
 * @returns 
 */
export function Update(obj:any) {
    // let tmp={id,img,start_time,end_time,address,title,type,recruitingpersonnel,registerserve,servicedescription,totalnumberoftimecoins,volunteergender,volunteerage,registrationisclosed}
    return axios.post<update_img>('/admin/api/v1/project/edi', obj);
}